@@ -45,8 +45,7 @@ import itertools
 
 from django.db import connection, models
 from django.db.models.aggregates import Aggregate
-from django.db.models.sql.aggregates import Aggregate as SQLAggregate, \
-    ordinal_aggregate_field, computed_aggregate_field
+from django.db.models.sql.aggregates import Aggregate as SQLAggregate
 
 from blingalytics import sources
 from blingalytics.utils.collections import OrderedDict
